@@ -4,7 +4,7 @@
  * Created Date: 28/05/2021
  * Author: Shun Suzuki
  * -----
- * Last Modified: 29/05/2021
+ * Last Modified: 03/06/2021
  * Modified By: Shun Suzuki (suzuki@hapis.k.u-tokyo.ac.jp)
  * -----
  * Copyright (c) 2021 Hapis Lab. All rights reserved.
@@ -15,6 +15,7 @@
 extern crate itertools;
 
 mod backend;
+mod combinational;
 mod error;
 mod linear_synthesis;
 mod macros;
@@ -22,6 +23,7 @@ mod matrix;
 mod nls;
 
 pub use backend::*;
+pub use combinational::*;
 pub use linear_synthesis::*;
 pub use matrix::*;
 pub use nls::*;
