@@ -4,7 +4,7 @@
  * Created Date: 28/05/2021
  * Author: Shun Suzuki
  * -----
- * Last Modified: 19/06/2021
+ * Last Modified: 21/07/2021
  * Modified By: Shun Suzuki (suzuki@hapis.k.u-tokyo.ac.jp)
  * -----
  * Copyright (c) 2021 Hapis Lab. All rights reserved.
@@ -79,10 +79,10 @@ pub fn set_from_complex_drive(
         } else {
             drive[j].abs() / max_coefficient
         };
-        let f_phase = drive[j].argument() / (2.0 * PI) + 0.5;
-        let phase = (((1.0 - f_phase) * 256.0) as u16) & 0xFF;
-        let duty = ((adjust_amp(f_amp) as u16) << 8) & 0xFF00;
-        data[dev_idx][trans_idx] = duty | phase;
+        let phase = drive[j].argument() / (2.0 * PI) + 0.5;
+        let phase = autd3_core::utils::to_phase(phase);
+        let duty = adjust_amp(f_amp);
+        data[dev_idx][trans_idx] = autd3_core::utils::pack_to_u16(duty, phase);
         trans_idx += 1;
         if trans_idx == NUM_TRANS_IN_UNIT {
             dev_idx += 1;
